<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Kirjaudu sisään sinun Deepin ID:llä.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Sinun tulee kirjautua sisään jatkaaksesi seuraavia toimintoja.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Olet tehnyt liian monta pyyntöä. Yritä myöhemmin uudelleen.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Sinun tulee kirjautua sisään jatkaaksesi seuraavia toimintoja.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Verkkovirhe, yritä myöhemmin</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Kirjautumaton</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Palautteeni</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Kirjaudu sisään</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 katselukertaa</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Ehdotukset</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Poista suosikki</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Peruuta vaatimus</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Vaatimus</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Tulossa</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Virallinen vastaus</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Haku</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typpi:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Bugi</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Ehdotukset</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versio:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Järjestys:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Uusin</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Kehotus</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Viestintä</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Keskustele ja jaa täällä</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Virhe raportti</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Ilmoita löytämistäsi ongelmista</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Ehdotukset</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Lähetä ehdotuksesi</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Resurssit</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Kyselylomake</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Liity meihin</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Sisäinen testaus</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Käännökset</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Yhteisön uutiset</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Ei enää kohteita</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Viestit</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Kyselylomakkeet</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Avaa käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin etusivu</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Nopea kirjautuminen foorumeille, ehdotusten lähettäminen ja virheiden ilmoitus.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Ei vielä viestejä</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 viestiä</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Merkitse kaikki luetuksi</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Katso lisää</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Verkkovirhe, yritä myöhemmin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Virkistä</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin etusivu</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Ei vielä kyselyitä.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Vanhentunut: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Täydennä</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Vireillä</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Kopiointi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Vahvistettu</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Vastattu</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Ratkaistu</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Arviointi</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Hyväksytty</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Ongelmaa ei ole käsitelty, eikä näytetä julkisessa listauksessa.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Syytä ei tällä hetkellä voida tunnistaa; tarvitaan syyn seurantaa ja tutkimusta.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Ongelma on toistettu ja perimmäinen syy on löydetty.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Ongelma ei ole bugi tai luonteeltaan erilainen.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Ongelma on ratkaistu ja odottaa virallista julkaisua</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Ilmoitusta ei ole käsitelty, eikä näytetä julkisessa listauksessa.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Ongelma on tunnustettu ja sitä arvioidaan</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Mukana tulevan julkaisun suunnitelmissa</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Ilmoitusta ei joko hyväksytä tai siihen ei voida vastata</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Kehitystyö on päättynyt ja odottaa virallista julkaisua</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Kuvien lisääminen ei onnistu.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Kuvatiedoston koon tulee olla alle 1 Mt.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Lähetettävää kuvan tiedostomuotoa ei tueta.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Tuotteen nykyinen tila]: 
[Tuote]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Edellytykset]: 
[Toistettavuuden vaiheet]: 
[Odotetut tulokset]: 
[Todelliset tulokset]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Anna palautetta</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Typpi：</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Ehdotukset</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Virhe raportti</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Otsikko：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Anna lyhyt kuvaus ongelmasta</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Sisältö：</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Älä täytä useita kysymyksiä samaan palautteeseen</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Älä täytä montaa vaatimusta yhteen palautteeseen</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Sähköposti：</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Anna sähköpostiosoitteesi</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Järjestelmän versio:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Laitteen tiedot：</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Lähetä &lt;a href=&apos;home://sysinfo&apos;&gt;laitteen tiedot&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Ruudunkaappaus：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Kuvatiedostot</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Vedä ja pudota tiedostoja tai paina painikkeita ja lisää kuvia, enintään kolme</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Haluatko varmasti poistua palautteen lähettämisestä?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Palautteen sisältöä ei tallenneta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Palautteen lähettäminen ei onnistu.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Anna palautteen otsikko ja sisältö.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Anna palautteesi otsikko.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Anna palautteesi sisältö.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Virheellinen sähköpostiosoite.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Laitteen tiedot</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Palautekeskus</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Palautteeni</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Minun ilmoitus</translation>
    </message>
</context>
</TS>